@@ -1,8 +1,8 @@
 package Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::TxnDo;
-BEGIN {
-  $Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::TxnDo::VERSION = '0.0.8.9';
+{
+  $Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::TxnDo::VERSION = '0.0.8.10';
 }
-BEGIN {
+{
   $Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::TxnDo::DIST = 'Catalyst-Plugin-ErrorCatcher';
 }
 use strict;
@@ -30,21 +30,22 @@ sub tidy_message {
 }
 
 1;
+# ABSTRACT: cleanup txn_do messages from Pg
 
 __END__
 =pod
 
 =head1 NAME
 
-Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::TxnDo
+Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::TxnDo - cleanup txn_do messages from Pg
 
 =head1 VERSION
 
-version 0.0.8.9
+version 0.0.8.10
 
 =head1 AUTHOR
 
-Chisel Wright <chisel@chizography.net>
+Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
